@@ -21,7 +21,7 @@ module.exports = function(weightedProperty, normalised) {
   var weightCalculatorFn = function() {
     var maxWeight = _.maxBy(collection, 'weight').weight;
     if (maxWeight === 0) {
-      logger.warn("Can't determine weight value of collection. Assigining 0 to every item.");
+      logger.warn("Can't determine weight of collection. Assigning a value of 0 to every item.");
       return _.constant(0);
     }
     if (isNormalised) {
