@@ -10,6 +10,7 @@ var _         = require('lodash'),
     Q         = require('q'),
     pp        = require('../parallel_processing'),
     reporting = require('../reporting'),
+    logger    = require('../log').Logger,
     utils     = require('../utils');
 
 module.exports = function(taskDef, context, helpers) {
@@ -59,8 +60,12 @@ module.exports = function(taskDef, context, helpers) {
               mergeStrategy: reporting.MergeStrategies.extension(['addedLines', 'deletedLines'])
             })
             .buildReport().then(function(reportData) {
-              var dataTree = helpers.graphData.weightedTree(reportData, 'path', 'couplingDegree');
-              return utils.json.objectToFile(publisher.addReportFile(period), dataTree);
+              if (_.some(reportData, 'couplingDegree')) {
+                var dataTree = helpers.graphData.weightedTree(reportData, 'path', 'couplingDegree');
+                return utils.json.objectToFile(publisher.addReportFile(period), dataTree);
+              } else {
+                logger.info('No coupling data available for period ', period.toString());
+              }
             });
         });
       });
