@@ -17,7 +17,7 @@ module.exports = function(context) {
     vcsNormalisedLog:  function(period) { return tempPath('vcslog_normalised_' + period.toString() + '.log'); },
     vcsCommitMessages: function(period) { return tempPath('vcs_commit_messages_' + period.toString() + '.log'); },
     sloc:              function() { return tempPath('sloc-report.json'); },
-    codeBoundaries:    function() { return tempPath('code_boundaries.txt'); },
+    layerGrouping:    function() { return tempPath('layer-grouping.txt'); },
     codeComplexity:    function(language) { return tempPath(language + '-complexity-report.json'); },
     revisions:         function() { return tempPath('revisions-report.json'); },
     authors:           function() { return tempPath('authors-report.json'); },
