@@ -1,5 +1,12 @@
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
 (function() {
-  System.config({
+  window.System.config({
     map: {
       lodash:   '/lib/lodash/lodash.js',
       knockout: '/lib/knockout/build/output/knockout-latest.js',
@@ -13,5 +20,5 @@
       'd3Cloud': { format: 'global', deps: ['d3'] }
     }
   });
-  System.import('/js/main.js').then(function(module) { module.run(); });
+  window.System.import('/js/main.js').then(function(module) { module.run(); });
 })();
