@@ -1,4 +1,12 @@
-var d3 = require('d3');
+/*
+ * code-forensics
+ * Copyright (C) 2016-2017 Silvio Montanari
+ * Distributed under the GNU General Public License v3.0
+ * see http://www.gnu.org/licenses/gpl.html
+ */
+
+var _  = require('lodash'),
+    d3 = require('d3');
 
 var TYPE = {
   default: _.identity,
